/*
 *  Copyright (C) 2010  Giorgio Wicklein <g.wicklein@giowisys.com>
 *
 *  This file is part of DaemonFS.
 *
 *  DaemonFS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DaemonFS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with DaemonFS.  If not, see <http://www.gnu.org/licenses/>.
 */

//-----------------------------------------------------------------------------
// Hearders
//-----------------------------------------------------------------------------

#include "startwidget.h"
#include "ui_startwidget.h"


//-----------------------------------------------------------------------------
// Public
//-----------------------------------------------------------------------------

StartWidget::StartWidget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::StartWidget)
{
    ui->setupUi(this);

    connect(ui->monitorButton, SIGNAL(clicked()), this, SIGNAL(monitorButtonClicked()));
    connect(ui->quitButton, SIGNAL(clicked()),
            qApp, SLOT(quit()));
    connect(ui->aboutButton, SIGNAL(clicked()),
            this, SIGNAL(aboutButtonClicked()));
}

StartWidget::~StartWidget()
{
    delete ui;
}
