/*
 *  Copyright (C) 2010  Giorgio Wicklein <g.wicklein@giowisys.com>
 *
 *  This file is part of DaemonFS.
 *
 *  DaemonFS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DaemonFS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with DaemonFS.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STARTWIDGET_H
#define STARTWIDGET_H

//-----------------------------------------------------------------------------
// Hearders
//-----------------------------------------------------------------------------

#include <QWidget>

namespace Ui {
    class StartWidget;
}

//-----------------------------------------------------------------------------
// StartWidget
//-----------------------------------------------------------------------------

class StartWidget : public QWidget
{
    Q_OBJECT

public:
    explicit StartWidget(QWidget *parent = 0);
    ~StartWidget();

signals:
    void monitorButtonClicked();
    void aboutButtonClicked();

private:
    Ui::StartWidget *ui;
};

#endif // STARTWIDGET_H
